@@ -1,6 +1,6 @@
 /*
 	dirtree.cc	Directory Tree Functions
-	Copyright (c) 2000 Kriang Lerdsuwanakij
+	Copyright (c) 2000,2002 Kriang Lerdsuwanakij
 	email:		lerdsuwa@users.sourceforge.net
 
 	This program is free software; you can redistribute it and/or modify
@@ -26,7 +26,7 @@
 
 sptr_list<DirectoryEntry> dirTree;
 
-const char	uniqueTag[] = "<KCDID#7>";	// File ID
+const char	uniqueTag[] = "<KCDID#8>";	// File ID
 const int	endianTest = 0x1234;		// For endian test
 
 /*************************************************************************
@@ -105,6 +105,10 @@ void	LoadDirHeader(gzFile filegz)
 	if (c != static_cast<char>(sizeof(long)))
 		throw ErrorBadFileFormat();
 
+	k_gzgetc(filegz, c);		// Size of bool
+	if (c != static_cast<char>(sizeof(bool)))
+		throw ErrorBadFileFormat();
+
 	k_gzgetc(filegz, c);		// Size of mode_t
 	if (c != static_cast<char>(sizeof(mode_t)))
 		throw ErrorBadFileFormat();
@@ -271,6 +275,7 @@ void	WriteDirFile()
 						// Variable size information
 		k_gzputc(file, static_cast<char>(sizeof(int)));
 		k_gzputc(file, static_cast<char>(sizeof(long)));
+		k_gzputc(file, static_cast<char>(sizeof(bool)));
 		k_gzputc(file, static_cast<char>(sizeof(mode_t)));
 		k_gzputc(file, static_cast<char>(sizeof(off_t)));
 		k_gzputc(file, static_cast<char>(sizeof(time_t)));
