@@ -36,6 +36,7 @@
 #endif
 
 #include CXX__HEADER_algorithm
+#include CXX__HEADER_fstream
 
 string	saveCwd;
 
@@ -864,8 +865,6 @@ void	CD(const string &linktext, bool entire_tree)
 {
 	LoadDirFile(1);
 
-	Buffer	buffer;
-
 	HyperDraw *drawObj = 0;
 
 	if (saveCwd.size())				// Current directory is available
@@ -932,6 +931,7 @@ void	CD(const string &linktext, bool entire_tree)
 
 #ifdef DUMP_HTML
 	{
+		Buffer	buffer;
 		int handle = open("/home/lerdsuwa/devel/kcd/debug", O_RDWR|O_CREAT, 0700);
 		write(handle, buffer.GetPtr(), strlen(buffer.GetPtr()));
 		close(handle);
@@ -1000,20 +1000,42 @@ void	CD(const string &linktext, bool entire_tree)
 	}
 }
 
-void	ShowBookmark(const string &linktext)
+/*************************************************************************
+	Bookmark helper functions
+*************************************************************************/
+
+void	AddBookmark(const string &str)
+{
+	string s = ExpandDirectory(str, false);
+	FindDirInfo *f = FindDir(s, true, false);
+	if (f)
+		f->dir_ptr->bookmarked = true;
+	else {
+		cout << flush;			// Avoid out-of-order display
+		gtout(cerr, _("%$: cannot find %$ in saved directory tree\n"
+			      "        Directory ignored"))
+		     << progName << s;
+	}
+}
+
+void	RemoveBookmark(const string &str)
+{
+	string s = ExpandDirectory(str, false);
+	FindDirInfo *f = FindDir(s, true, false);
+	if (f)
+		f->dir_ptr->bookmarked = false;
+	else {
+		cout << flush;			// Avoid out-of-order display
+		gtout(cerr, _("%$: cannot find %$ in saved directory tree\n"
+			      "        Directory ignored"))
+		     << progName << s;
+	}
+}
+
+void	GetBookmarks(list<MatchInfo> &match_list, const string &linktext)
 {
 	LoadDirFile(1);
 
-	Buffer	buffer;
-
-	HyperDraw *drawObj = 0;
-
-	string	hyperInitPos;
-	string	hyperFindLink;
-	
-	GenerateHTMLStrings();
-
-	list<MatchInfo>	match_list;
 	if (linktext.size()) {
 		FindMatchDir(match_list, linktext);
 							// Remove entries not
@@ -1023,6 +1045,76 @@ void	ShowBookmark(const string &linktext)
 	else {
 		FindBookmarkedDir(match_list);
 	}
+}
+
+void	ExportBookmarks(const string &filename, const list<MatchInfo> &match_list)
+{
+	const char *	s;
+	if (filename.size())
+		s = filename.c_str();
+	else
+		s = bookmarkFile.c_str();
+
+	ofstream ofs(s);
+	if (!ofs) {
+		throw ErrorGenericFile(_("cannot create file %$"), s);
+	}
+
+	for (list<MatchInfo>::const_iterator iter = match_list.begin();
+	     iter != match_list.end(); iter++) {
+		ofs << iter->name << '\n';
+		if (!ofs)
+			throw ErrorGenericFile(_("error writing file %$"), s);
+	}
+}
+
+/*************************************************************************
+	Bookmark functions
+*************************************************************************/
+
+void	ImportBookmarks(const string &filename, bool load)
+{
+	if (load)
+		LoadDirFile(1);
+
+	const char *	s;
+	if (filename.size())
+		s = filename.c_str();
+	else
+		s = bookmarkFile.c_str();
+
+	ifstream ifs(s);
+	if (!ifs) {
+		throw ErrorGenericFile(_("cannot read file %$"), s);
+	}
+
+	for ( ; ; ) {
+		string	buffer;
+		getline(ifs, buffer);
+		if (ifs.eof())
+			break;
+		if (!ifs)
+			throw ErrorGenericFile(_("error reading file %$"), s);
+		AddBookmark(buffer);
+	}
+}
+
+void	ExportBookmarks(const string &filename, bool load)
+{
+	if (load)
+		LoadDirFile(1);
+
+	list<MatchInfo>	match_list;
+	GetBookmarks(match_list, "");
+	ExportBookmarks(filename, match_list);
+}
+
+void	ShowBookmarks(const string &linktext)
+{
+	LoadDirFile(1);
+
+	list<MatchInfo>	match_list;
+	GetBookmarks(match_list, linktext);
 
 	if (!match_list.size()) {
 		cout << flush;			// Avoid out-of-order display
@@ -1031,10 +1123,12 @@ void	ShowBookmark(const string &linktext)
 		return;
 	}
 
-	drawObj = new HyperListDraw(match_list);
+	GenerateHTMLStrings();
+
+	HyperDraw *drawObj = new HyperListDraw(match_list);
 			
-	hyperInitPos = "";
-	hyperFindLink = "";
+	string	hyperInitPos = "";
+	string	hyperFindLink = "";
 			
 	HyperDocument		*html = new HyperDocument(drawObj);
 
@@ -1098,34 +1192,6 @@ void	ShowBookmark(const string &linktext)
 	}
 }
 
-void	AddBookmark(const string &str)
-{
-	string s = ExpandDirectory(str, false);
-	FindDirInfo *f = FindDir(s, true, false);
-	if (f)
-		f->dir_ptr->bookmarked = true;
-	else {
-		cout << flush;			// Avoid out-of-order display
-		gtout(cerr, _("%$: cannot find %$ in saved directory tree\n"
-			      "        Directory ignored"))
-		     << progName << s;
-	}
-}
-
-void	RemoveBookmark(const string &str)
-{
-	string s = ExpandDirectory(str, false);
-	FindDirInfo *f = FindDir(s, true, false);
-	if (f)
-		f->dir_ptr->bookmarked = false;
-	else {
-		cout << flush;			// Avoid out-of-order display
-		gtout(cerr, _("%$: cannot find %$ in saved directory tree\n"
-			      "        Directory ignored"))
-		     << progName << s;
-	}
-}
-
 void	AddBookmarks(int argc, char *argv[], int argcBegin)
 {
 	LoadDirFile(1);
@@ -1166,6 +1232,7 @@ void	AddBookmarks(int argc, char *argv[], int argcBegin)
 	}
 
 	WriteDirFile();
+	ExportBookmarks("", false);
 }
 
 void	RemoveBookmarks(int argc, char *argv[], int argcBegin)
@@ -1208,4 +1275,5 @@ void	RemoveBookmarks(int argc, char *argv[], int argcBegin)
 	}
 
 	WriteDirFile();
+	ExportBookmarks("", false);
 }
