@@ -46,6 +46,7 @@
 char	progName[] = "kcd";
 
 string	saveFile;		// For home dir + ".kcd.save.gz"
+string	bookmarkFile;		// For home dir + ".kcd.bookmark.gz"
 string	dirFile;		// For home dir + ".kcd.newdir"
 string	confLocalFile;		// For home dir + ".kcd.conf"
 
@@ -98,6 +99,7 @@ void	Help()
 		  "                    (default = display all)\n"
 		  "     -ba [DIR ...]  Bookmark DIR list (default = current directory)\n"
 		  "     -br [DIR ...]  Remove DIR list bookmark\n"
+		  "     -bx [FILE]     Export bookmark to FILE\n"
 		  "     -B             Use entire tree even a bookmarked match is found\n");
 	cout << _("     --config       Display current configuration\n"
 		  "     --configattr   Display current screen attribute configuration\n"
@@ -204,7 +206,7 @@ string	home_dir;
 
 void	SetSaveFile()
 {
-					// Initialize ~/.kcd.save.gz,
+					// Initialize ~/.kcd.save.*.gz,
 	if (getenv("KCD_DIRTREE") && strlen(getenv("KCD_DIRTREE"))) {
 		saveFile = getenv("KCD_DIRTREE");
 	}
@@ -212,7 +214,17 @@ void	SetSaveFile()
 		saveFile = home_dir;
 		saveFile += ".kcd.save.";
 		saveFile += GetCurrentProfile();
-		saveFile += ".gz";	// Add appropriate filename
+		saveFile += ".gz";
+	}
+
+					// Initialize ~/.kcd.bookmark.*.gz,
+	if (getenv("KCD_BOOKMARK") && strlen(getenv("KCD_BOOKMARK"))) {
+		bookmarkFile = getenv("KCD_BOOKMARK");
+	}
+	else {
+		bookmarkFile = home_dir;
+		bookmarkFile += ".kcd.bookmark.";
+		bookmarkFile += GetCurrentProfile();
 	}
 }
 
@@ -415,9 +427,9 @@ void	mainReal(int argc, char *argv[])
 				if (argcLeft >= 3)
 					throw ErrorGenericCommandLine(_("too many arguments for `-b\'"));
 				else if (argcLeft == 2)
-					ShowBookmark(argv[argcCur+1]);
+					ShowBookmarks(argv[argcCur+1]);
 				else
-					ShowBookmark("");
+					ShowBookmarks("");
 				return;
 			}
 						// Add bookmark
@@ -431,6 +443,18 @@ void	mainReal(int argc, char *argv[])
 				SetSaveFile();
 				RemoveBookmarks(argc, argv, argcCur+1);
 				return;
+			}
+						// Export bookmark
+			else if (strcmp(argv[argcCur], "-bx") == 0) {
+				SetSaveFile();
+
+				if (argcLeft >= 3)
+					throw ErrorGenericCommandLine(_("too many arguments for `-bx\'"));
+				else if (argcLeft == 2)
+					ExportBookmarks(argv[argcCur+1], true);
+				else
+					ExportBookmarks("", true);
+				return;
 			}
 						// Use entire tree
 			else if (strcmp(argv[argcCur], "-B") == 0) {
