@@ -121,7 +121,7 @@ void	khStatusWindow::NextStatus()
 	DrawStatusBar();
 }
 
-void	khStatusWindow::DrawStatusBar(int num = -1)
+void	khStatusWindow::DrawStatusBar(int num)
 {
 	if (num == -1)
 		num = statusNo;
@@ -221,7 +221,7 @@ void	khURLWindow::ProcessMouse(MEVENT &event)
 }
 #endif
 
-void	khURLWindow::DrawStatusBar(int num = -1)
+void	khURLWindow::DrawStatusBar(int num)
 {
 	if (num == -1)
 		num = statusNo;
@@ -300,7 +300,7 @@ void	khURLWindowWithFind::ProcessCtrl(char /*c*/, bool s)
 	scrnMan.RequestUpdate();
 }
 
-void	khURLWindowWithFind::DrawStatusBar(int num = -1)
+void	khURLWindowWithFind::DrawStatusBar(int num)
 {
 	if (num == -1)
 		num = statusNo;
@@ -349,7 +349,7 @@ char	*khStatusWindowWithFind::statFindIns = N_("Ins");
 
 int	khStatusWindowWithFind::spaceSelect = 1;	// Default = true
 
-void	khStatusWindowWithFind::DrawStatusBar(int num = -1)
+void	khStatusWindowWithFind::DrawStatusBar(int num)
 {
 	editBox->SetWin(win);		// Update editBox when called from
 					// khStatusWindow::Init() after window
